# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: client_storage.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'client_storage.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14\x63lient_storage.proto\x12\x05proto\x1a\x1fgoogle/protobuf/timestamp.proto\"5\n\x13\x43reateBucketRequest\x12\x0e\n\x06\x62ucket\x18\x01 \x01(\t\x12\x0e\n\x06region\x18\x02 \x01(\t\"(\n\x14\x43reateBucketResponse\x12\x10\n\x08Location\x18\x01 \x01(\t\"%\n\x13\x44\x65leteBucketRequest\x12\x0e\n\x06\x62ucket\x18\x01 \x01(\t\"\x16\n\x14\x44\x65leteBucketResponse\"\x14\n\x12ListBucketsRequest\"U\n\x13ListBucketsResponse\x12\x1e\n\x07\x62uckets\x18\x01 \x03(\x0b\x32\r.proto.Bucket\x12\x13\n\x06prefix\x18\x02 \x01(\tH\x00\x88\x01\x01\x42\t\n\x07_prefix\"#\n\x11HeadBucketRequest\x12\x0e\n\x06\x62ucket\x18\x01 \x01(\t\"*\n\x12HeadBucketResponse\x12\x14\n\x0c\x62ucketRegion\x18\x01 \x01(\t\"Y\n\x0ePutObjectInput\x12\x0e\n\x06\x62ucket\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\x19\n\x0cisCompressed\x18\x03 \x01(\x08H\x00\x88\x01\x01\x42\x0f\n\r_isCompressed\"X\n\x10PutObjectRequest\x12+\n\nparameters\x18\x01 \x01(\x0b\x32\x15.proto.PutObjectInputH\x00\x12\x0f\n\x05\x63hunk\x18\x02 \x01(\x0cH\x00\x42\x06\n\x04\x64\x61ta\"\x13\n\x11PutObjectResponse\"/\n\x10GetObjectRequest\x12\x0e\n\x06\x62ucket\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\"Z\n\x11GetObjectResponse\x12,\n\x08metadata\x18\x02 \x01(\x0b\x32\x18.proto.GetObjectMetadataH\x00\x12\x0f\n\x05\x63hunk\x18\x03 \x01(\x0cH\x00\x42\x06\n\x04\x64\x61ta\"2\n\x13\x44\x65leteObjectRequest\x12\x0e\n\x06\x62ucket\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\"\x16\n\x14\x44\x65leteObjectResponse\"P\n\x14\x44\x65leteObjectsRequest\x12\x0e\n\x06\x62ucket\x18\x01 \x01(\t\x12(\n\x07objects\x18\x02 \x03(\x0b\x32\x17.proto.ObjectIdentifier\"E\n\x15\x44\x65leteObjectsResponse\x12,\n\x0e\x64\x65letedObjects\x18\x01 \x03(\x0b\x32\x14.proto.DeletedObject\"D\n\x11\x43opyObjectRequest\x12\x0e\n\x06\x62ucket\x18\x01 \x01(\t\x12\x12\n\ncopySource\x18\x02 \x01(\t\x12\x0b\n\x03key\x18\x03 \x01(\t\"\x14\n\x12\x43opyObjectResponse\"0\n\x11HeadObjectRequest\x12\x0e\n\x06\x62ucket\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\"=\n\x12HeadObjectResponse\x12\'\n\x08metadata\x18\x02 \x01(\x0b\x32\x15.proto.ObjectMetadata\"\x92\x01\n\x12ListObjectsRequest\x12\x0e\n\x06\x62ucket\x18\x01 \x01(\t\x12\x13\n\x06prefix\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x18\n\x0bstart_after\x18\x03 \x01(\tH\x01\x88\x01\x01\x12\x15\n\x08max_keys\x18\x04 \x01(\x05H\x02\x88\x01\x01\x42\t\n\x07_prefixB\x0e\n\x0c_start_afterB\x0b\n\t_max_keys\"u\n\x13ListObjectsResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1a.proto.ListObjectsMetadataH\x00\x12&\n\x06object\x18\x02 \x01(\x0b\x32\x14.proto.ObjectSummaryH\x00\x42\x06\n\x04\x64\x61ta\"?\n\x0b\x41uthRequest\x12\x15\n\raccess_key_id\x18\x01 \x01(\t\x12\x19\n\x11secret_access_key\x18\x02 \x01(\t\"\x0e\n\x0c\x41uthResponse\"G\n\x10RotateKeyRequest\x12\x15\n\raccess_key_id\x18\x01 \x01(\t\x12\x12\n\x05\x66orce\x18\x02 \x01(\x08H\x00\x88\x01\x01\x42\x08\n\x06_force\"C\n\x11RotateKeyResponse\x12\x0f\n\x07rotated\x18\x01 \x01(\x08\x12\x1d\n\x15new_secret_access_key\x18\x02 \x01(\t\"(\n\x12ShareBucketRequest\x12\x12\n\nbucketName\x18\x01 \x01(\t\"\x15\n\x13ShareBucketResponse\"\x13\n\x11GetObjectMetadata\"Z\n\x13ListObjectsMetadata\x12\x0e\n\x06\x62ucket\x18\x01 \x01(\t\x12\x0e\n\x06prefix\x18\x02 \x01(\t\x12\x12\n\nstartAfter\x18\x03 \x01(\t\x12\x0f\n\x07maxKeys\x18\x04 \x01(\x05\"C\n\x06\x42ucket\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x15\n\rcreation_date\x18\x02 \x01(\t\x12\x14\n\x0c\x62ucketRegion\x18\x03 \x01(\t\"\xd2\x02\n\x0eObjectMetadata\x12\x0c\n\x04size\x18\x01 \x01(\x03\x12\x31\n\rlast_modified\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04\x65tag\x18\x03 \x01(\t\x12\x14\n\x0c\x63ontent_type\x18\x04 \x01(\t\x12\x18\n\x10\x63ontent_encoding\x18\x05 \x01(\t\x12\x18\n\x10\x63ontent_language\x18\x06 \x01(\t\x12\x12\n\nversion_id\x18\x07 \x01(\t\x12\x1e\n\x16server_side_encryption\x18\x08 \x01(\t\x12>\n\ruser_metadata\x18\t \x03(\x0b\x32\'.proto.ObjectMetadata.UserMetadataEntry\x1a\x33\n\x11UserMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"k\n\rObjectSummary\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x0c\n\x04size\x18\x02 \x01(\x03\x12\x31\n\rlast_modified\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04\x65tag\x18\x04 \x01(\t\"\x1f\n\x10ObjectIdentifier\x12\x0b\n\x03key\x18\x01 \x01(\t\"\x1c\n\rDeletedObject\x12\x0b\n\x03key\x18\x01 \x01(\t2\xf1\x07\n\x12ObjectStorageCache\x12I\n\x0c\x43reateBucket\x12\x1a.proto.CreateBucketRequest\x1a\x1b.proto.CreateBucketResponse\"\x00\x12I\n\x0c\x44\x65leteBucket\x12\x1a.proto.DeleteBucketRequest\x1a\x1b.proto.DeleteBucketResponse\"\x00\x12\x46\n\x0bListBuckets\x12\x19.proto.ListBucketsRequest\x1a\x1a.proto.ListBucketsResponse\"\x00\x12\x43\n\nHeadBucket\x12\x18.proto.HeadBucketRequest\x1a\x19.proto.HeadBucketResponse\"\x00\x12\x42\n\tPutObject\x12\x17.proto.PutObjectRequest\x1a\x18.proto.PutObjectResponse\"\x00(\x01\x12\x42\n\tGetObject\x12\x17.proto.GetObjectRequest\x1a\x18.proto.GetObjectResponse\"\x00\x30\x01\x12I\n\x0c\x44\x65leteObject\x12\x1a.proto.DeleteObjectRequest\x1a\x1b.proto.DeleteObjectResponse\"\x00\x12L\n\rDeleteObjects\x12\x1b.proto.DeleteObjectsRequest\x1a\x1c.proto.DeleteObjectsResponse\"\x00\x12\x43\n\nCopyObject\x12\x18.proto.CopyObjectRequest\x1a\x19.proto.CopyObjectResponse\"\x00\x12\x43\n\nHeadObject\x12\x18.proto.HeadObjectRequest\x1a\x19.proto.HeadObjectResponse\"\x00\x12H\n\x0bListObjects\x12\x19.proto.ListObjectsRequest\x1a\x1a.proto.ListObjectsResponse\"\x00\x30\x01\x12\x39\n\x0c\x41uthenticate\x12\x12.proto.AuthRequest\x1a\x13.proto.AuthResponse\"\x00\x12@\n\tRotateKey\x12\x17.proto.RotateKeyRequest\x1a\x18.proto.RotateKeyResponse\"\x00\x12\x46\n\x0bShareBucket\x12\x19.proto.ShareBucketRequest\x1a\x1a.proto.ShareBucketResponse\"\x00\x42\x03\x90\x01\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'client_storage_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\220\001\001'
  _globals['_OBJECTMETADATA_USERMETADATAENTRY']._loaded_options = None
  _globals['_OBJECTMETADATA_USERMETADATAENTRY']._serialized_options = b'8\001'
  _globals['_CREATEBUCKETREQUEST']._serialized_start=64
  _globals['_CREATEBUCKETREQUEST']._serialized_end=117
  _globals['_CREATEBUCKETRESPONSE']._serialized_start=119
  _globals['_CREATEBUCKETRESPONSE']._serialized_end=159
  _globals['_DELETEBUCKETREQUEST']._serialized_start=161
  _globals['_DELETEBUCKETREQUEST']._serialized_end=198
  _globals['_DELETEBUCKETRESPONSE']._serialized_start=200
  _globals['_DELETEBUCKETRESPONSE']._serialized_end=222
  _globals['_LISTBUCKETSREQUEST']._serialized_start=224
  _globals['_LISTBUCKETSREQUEST']._serialized_end=244
  _globals['_LISTBUCKETSRESPONSE']._serialized_start=246
  _globals['_LISTBUCKETSRESPONSE']._serialized_end=331
  _globals['_HEADBUCKETREQUEST']._serialized_start=333
  _globals['_HEADBUCKETREQUEST']._serialized_end=368
  _globals['_HEADBUCKETRESPONSE']._serialized_start=370
  _globals['_HEADBUCKETRESPONSE']._serialized_end=412
  _globals['_PUTOBJECTINPUT']._serialized_start=414
  _globals['_PUTOBJECTINPUT']._serialized_end=503
  _globals['_PUTOBJECTREQUEST']._serialized_start=505
  _globals['_PUTOBJECTREQUEST']._serialized_end=593
  _globals['_PUTOBJECTRESPONSE']._serialized_start=595
  _globals['_PUTOBJECTRESPONSE']._serialized_end=614
  _globals['_GETOBJECTREQUEST']._serialized_start=616
  _globals['_GETOBJECTREQUEST']._serialized_end=663
  _globals['_GETOBJECTRESPONSE']._serialized_start=665
  _globals['_GETOBJECTRESPONSE']._serialized_end=755
  _globals['_DELETEOBJECTREQUEST']._serialized_start=757
  _globals['_DELETEOBJECTREQUEST']._serialized_end=807
  _globals['_DELETEOBJECTRESPONSE']._serialized_start=809
  _globals['_DELETEOBJECTRESPONSE']._serialized_end=831
  _globals['_DELETEOBJECTSREQUEST']._serialized_start=833
  _globals['_DELETEOBJECTSREQUEST']._serialized_end=913
  _globals['_DELETEOBJECTSRESPONSE']._serialized_start=915
  _globals['_DELETEOBJECTSRESPONSE']._serialized_end=984
  _globals['_COPYOBJECTREQUEST']._serialized_start=986
  _globals['_COPYOBJECTREQUEST']._serialized_end=1054
  _globals['_COPYOBJECTRESPONSE']._serialized_start=1056
  _globals['_COPYOBJECTRESPONSE']._serialized_end=1076
  _globals['_HEADOBJECTREQUEST']._serialized_start=1078
  _globals['_HEADOBJECTREQUEST']._serialized_end=1126
  _globals['_HEADOBJECTRESPONSE']._serialized_start=1128
  _globals['_HEADOBJECTRESPONSE']._serialized_end=1189
  _globals['_LISTOBJECTSREQUEST']._serialized_start=1192
  _globals['_LISTOBJECTSREQUEST']._serialized_end=1338
  _globals['_LISTOBJECTSRESPONSE']._serialized_start=1340
  _globals['_LISTOBJECTSRESPONSE']._serialized_end=1457
  _globals['_AUTHREQUEST']._serialized_start=1459
  _globals['_AUTHREQUEST']._serialized_end=1522
  _globals['_AUTHRESPONSE']._serialized_start=1524
  _globals['_AUTHRESPONSE']._serialized_end=1538
  _globals['_ROTATEKEYREQUEST']._serialized_start=1540
  _globals['_ROTATEKEYREQUEST']._serialized_end=1611
  _globals['_ROTATEKEYRESPONSE']._serialized_start=1613
  _globals['_ROTATEKEYRESPONSE']._serialized_end=1680
  _globals['_SHAREBUCKETREQUEST']._serialized_start=1682
  _globals['_SHAREBUCKETREQUEST']._serialized_end=1722
  _globals['_SHAREBUCKETRESPONSE']._serialized_start=1724
  _globals['_SHAREBUCKETRESPONSE']._serialized_end=1745
  _globals['_GETOBJECTMETADATA']._serialized_start=1747
  _globals['_GETOBJECTMETADATA']._serialized_end=1766
  _globals['_LISTOBJECTSMETADATA']._serialized_start=1768
  _globals['_LISTOBJECTSMETADATA']._serialized_end=1858
  _globals['_BUCKET']._serialized_start=1860
  _globals['_BUCKET']._serialized_end=1927
  _globals['_OBJECTMETADATA']._serialized_start=1930
  _globals['_OBJECTMETADATA']._serialized_end=2268
  _globals['_OBJECTMETADATA_USERMETADATAENTRY']._serialized_start=2217
  _globals['_OBJECTMETADATA_USERMETADATAENTRY']._serialized_end=2268
  _globals['_OBJECTSUMMARY']._serialized_start=2270
  _globals['_OBJECTSUMMARY']._serialized_end=2377
  _globals['_OBJECTIDENTIFIER']._serialized_start=2379
  _globals['_OBJECTIDENTIFIER']._serialized_end=2410
  _globals['_DELETEDOBJECT']._serialized_start=2412
  _globals['_DELETEDOBJECT']._serialized_end=2440
  _globals['_OBJECTSTORAGECACHE']._serialized_start=2443
  _globals['_OBJECTSTORAGECACHE']._serialized_end=3452
_builder.BuildServices(DESCRIPTOR, 'client_storage_pb2', _globals)
# @@protoc_insertion_point(module_scope)
